Method

Enum Method 

pub enum Method {
Show 47 variants Initialize, IdentityGet, IssueList, IssueGet, IssueReady, IssueSearch, IssueClaims, IssueAgenda, IssueShow, IssueExcerpt, IssueTree, IssueRelated, IssueChildren, IssueAncestors, IssueImpact, IssueBacklinks, IssueOpen, IssueCreate, IssueUpdate, IssueClaim, IssueNote, IssueRefile, IssueAppend, IssueReject, IssueResolve, IssueVote, IssueDeed, IssueRecall, IssueConsensus, IssueFold, IssueNormalize, IssueCheck, IssueCount, IssueCycles, IssueDigest, IssueExport, IssueGraph, IssueRoadmap, IssueStale, IssueHygiene, IssueWaitingOn, IssueMirror, EventsPing, EventsWait, ProjectList, EventsSince, EventsGen,
}
v1 methods the owner advertises on initialize.

Variants



Initialize

Handshake. Not listed in V1_CAPABILITIES.



IdentityGet

Process identity, root, prefix, and crate version.



IssueList

Filtered issue rows.



IssueGet

One issue plus revision.



IssueReady

Frontier: issue/list with ready: true.



IssueSearch

Substring search over id, title, properties, tags, and body.



IssueClaims

Live claims.



IssueAgenda

Deadlines and scheduled starts.



IssueShow

Alias of Self::IssueGet.



IssueExcerpt

Secret-screened body range.



IssueTree

Children and blockers.



IssueRelated

Bounded neighborhood with evidence.



IssueChildren

Direct children.



IssueAncestors

Walk up the blocker graph.



IssueImpact

Walk down the blocker graph.

Everything pointing at the id.



IssueOpen

Shared selection; notifies issue/selected.



IssueCreate

Create an issue.



IssueUpdate

State, priority, block, unblock.



IssueClaim

Take the issue.



IssueNote

Dated logbook entry.



IssueRefile

Move to another project.



IssueAppend

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueReject

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueResolve

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueVote

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueDeed

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueRecall

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueConsensus

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueFold

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueNormalize

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueCheck

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueCount

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueCycles

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueDigest

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueExport

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueGraph

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueRoadmap

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueStale

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueHygiene

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueWaitingOn

Operation added after v1’s first draft; see schema/vissue.capnp.



IssueMirror

Operation added after v1’s first draft; see schema/vissue.capnp.



EventsPing

Operation added after v1’s first draft; see schema/vissue.capnp.



EventsWait

Operation added after v1’s first draft; see schema/vissue.capnp.



ProjectList

Project names plus revision.



EventsSince

Pull of the on-disk event log.



EventsGen

Current generation and revision.

Implementations

Source

impl Method

pub fn as_str(self) -> &'static str

Wire method name.

pub fn parse(name: &str) -> Result<Self, JsonRpcError>

Parse a v1 wire name.

Errors

Returns an error when name is not a v1 method.