pub struct DigestResult {
pub combined: String,
pub issues: usize,
pub generation: u64,
pub projects: Vec<ProjectDigestResult>,
}Expand description
issue/digest reply.
Fields
combined: StringHash over the per-project digests.
issues: usizeSum of the per-project issue counts.
generation: u64Event-log generation the digest was taken at, so two digests can be placed in time relative to each other.
projects: Vec<ProjectDigestResult>Per project, sorted by name.