pub struct WaitParams {
pub last: u64,
pub id: Option<String>,
pub poll_ms: Option<u64>,
pub timeout_ms: Option<u64>,
}Expand description
events/wait params. Waits for the corpus generation to pass last, or for
id to reach a terminal state when one is given.
Fields
last: u64Generation to wait past.
id: Option<String>Wait for this issue to reach a terminal state instead.
poll_ms: Option<u64>Poll interval in milliseconds.
timeout_ms: Option<u64>Give up after this many milliseconds.