decode_response

Function decode_response 

pub fn decode_response(method: &str, value: Value) -> Result<Response, Error>
Decode a typed Response from a raw result when the method is known.

Errors

Returns an error when method is not a v1 method or value does not match that method’s result shape.